@@ -3,17 +3,17 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Manipulate the position of a note in a scale
 
-our $VERSION = '0.0503';
+our $VERSION = '0.0504';
 
 use Carp;
-use Moo;
-use strictures 2;
-use namespace::clean;
-
 use List::Util qw( first );
+use Moo;
 use Music::Note;
 use Music::Scales;
 
+use strictures 2;
+use namespace::clean;
+
 
 has scale_note => (
     is      => 'ro',
@@ -128,22 +128,33 @@ Music::ScaleNote - Manipulate the position of a note in a scale
 
 =head1 VERSION
 
-version 0.0503
+version 0.0504
 
 =head1 SYNOPSIS
 
   use Music::ScaleNote;
 
   my $msn = Music::ScaleNote->new(
-    scale_note => 'C',
-    scale_name => 'pminor',
-    verbose    => 1,
+    scale_note  => 'C',
+    scale_name  => 'pminor',
+    note_format => 'ISO',
+    offset      => 1,
+    verbose     => 1,
   );
 
   my $note = $msn->get_offset( note_name => 'C4' );
-
   print $note->format('ISO'), "\n"; # D#4
 
+  $msn = Music::ScaleNote->new(
+    scale_note  => 'C',
+    scale_name  => 'major',
+    note_format => 'midinum',
+    offset      => -1,
+    verbose     => 1,
+  );
+  $note = $msn->get_offset( note_name => 60 );
+  print $note->format('midinum'), "\n"; # 59
+
 =head1 DESCRIPTION
 
 A C<Music::ScaleNote> object manipulates the position of a note in a scale.
@@ -156,7 +167,7 @@ So for scale C<C D# F G A#> (C pentatonic minor), note name C<C4> (given the
 ISO format), and offset C<1> (move one scale step to the right), this module
 will return C<D#4>.
 
-For offset C<-1>, C<A#3> is returned.
+For offset of C<-1>, the note C<A#3> is returned.
 
 =head1 ATTRIBUTES
 
